@@ -185,9 +185,13 @@ gcm_calibrate_argyll_get_sensor_image_attach (GcmCalibrateArgyll *calibrate_argy
 	if (sensor_kind == CD_SENSOR_KIND_COLORIMTRE_HCFR)
 		return "hcfr-attach.svg";
 	if (sensor_kind == CD_SENSOR_KIND_I1_PRO)
-		return "i1-attach.svg";
+		return "i1-pro-attach.svg";
 	if (sensor_kind == CD_SENSOR_KIND_DTP94)
 		return "dtp94-attach.svg";
+#if CD_CHECK_VERSION(0,1,14)
+	if (sensor_kind == CD_SENSOR_KIND_I1_DISPLAY3)
+		return "i1-display3-attach.svg";
+#endif
 	return NULL;
 }
 
@@ -2087,7 +2091,7 @@ gcm_calibrate_argyll_exit_cb (VteTerminal *terminal, GcmCalibrateArgyll *calibra
 static gboolean
 gcm_calibrate_argyll_timeout_cb (GcmCalibrateArgyll *calibrate_argyll)
 {
-	vte_terminal_feed_child (VTE_TERMINAL(calibrate_argyll->priv->terminal), " ", 1);
+	vte_terminal_feed_child (VTE_TERMINAL(calibrate_argyll->priv->terminal), "\n", 1);
 	return FALSE;
 }
 
@@ -2134,7 +2138,7 @@ gcm_calibrate_argyll_interaction_attach (GcmCalibrateArgyll *calibrate_argyll)
 	gcm_calibrate_interaction_required (GCM_CALIBRATE (calibrate_argyll), _("Continue"));
 
 	/* set state */
-	priv->argyllcms_ok = " ";
+	priv->argyllcms_ok = "\n";
 	priv->state = GCM_CALIBRATE_ARGYLL_STATE_WAITING_FOR_STDIN,
 
 	/* play sound from the naming spec */
@@ -2168,6 +2172,7 @@ gcm_calibrate_argyll_interaction_calibrate (GcmCalibrateArgyll *calibrate_argyll
 
 	/* get the image, if we have one */
 	filename = gcm_calibrate_argyll_get_sensor_image_calibrate (calibrate_argyll);
+	gcm_calibrate_set_image (GCM_CALIBRATE (calibrate_argyll), filename);
 
 	if (filename != NULL) {
 		/* TRANSLATORS: this is when the user has to change a setting on the sensor, and we're showing a picture */
@@ -2194,7 +2199,7 @@ gcm_calibrate_argyll_interaction_calibrate (GcmCalibrateArgyll *calibrate_argyll
 	priv->done_calibrate = TRUE;
 
 	/* set state */
-	priv->argyllcms_ok = " ";
+	priv->argyllcms_ok = "\n";
 	priv->state = GCM_CALIBRATE_ARGYLL_STATE_WAITING_FOR_STDIN;
 	gcm_calibrate_interaction_required (GCM_CALIBRATE (calibrate_argyll), _("Continue"));
 }
@@ -2217,6 +2222,7 @@ gcm_calibrate_argyll_interaction_surface (GcmCalibrateArgyll *calibrate_argyll)
 
 	/* get the image, if we have one */
 	filename = gcm_calibrate_argyll_get_sensor_image_screen (calibrate_argyll);
+	gcm_calibrate_set_image (GCM_CALIBRATE (calibrate_argyll), filename);
 
 	if (filename != NULL) {
 		/* TRANSLATORS: this is when the user has to change a setting on the sensor, and we're showing a picture */
@@ -2240,7 +2246,7 @@ gcm_calibrate_argyll_interaction_surface (GcmCalibrateArgyll *calibrate_argyll)
 	priv->already_on_window = FALSE;
 
 	/* set state */
-	priv->argyllcms_ok = " ";
+	priv->argyllcms_ok = "\n";
 	priv->state = GCM_CALIBRATE_ARGYLL_STATE_WAITING_FOR_STDIN;
 	gcm_calibrate_interaction_required (GCM_CALIBRATE (calibrate_argyll), _("Continue"));
 }
@@ -2296,7 +2302,7 @@ gcm_calibrate_argyll_process_output_cmd (GcmCalibrateArgyll *calibrate_argyll, c
 
 
 		/* set state */
-		priv->argyllcms_ok = " ";
+		priv->argyllcms_ok = "\n";
 		priv->state = GCM_CALIBRATE_ARGYLL_STATE_WAITING_FOR_STDIN;
 		gcm_calibrate_interaction_required (GCM_CALIBRATE (calibrate_argyll), _("Retry"));
 
@@ -2413,7 +2419,7 @@ gcm_calibrate_argyll_process_output_cmd (GcmCalibrateArgyll *calibrate_argyll, c
 					   _("Failed to read the strip correctly."));
 
 		/* set state */
-		priv->argyllcms_ok = " ";
+		priv->argyllcms_ok = "\n";
 		priv->state = GCM_CALIBRATE_ARGYLL_STATE_WAITING_FOR_STDIN;
 		gcm_calibrate_interaction_required (GCM_CALIBRATE (calibrate_argyll), _("Retry"));
 
