@@ -81,58 +81,6 @@ gcm_utils_linkify (const gchar *hostile_text)
 	return g_string_free (string, FALSE);
 }
 
-/**
- * gcm_utils_is_icc_profile:
- **/
-gboolean
-gcm_utils_is_icc_profile (GFile *file)
-{
-	GFileInfo *info;
-	const gchar *type;
-	GError *error = NULL;
-	gboolean ret = FALSE;
-	gchar *filename = NULL;
-
-	/* get content type for file */
-	filename = g_file_get_uri (file);
-	if (filename == NULL)
-		filename = g_file_get_path (file);
-	info = g_file_query_info (file, G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE, G_FILE_QUERY_INFO_NONE, NULL, &error);
-	if (info != NULL) {
-		type = g_file_info_get_attribute_string (info, G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE);
-		if (g_strcmp0 (type, "application/vnd.iccprofile") == 0) {
-			ret = TRUE;
-			goto out;
-		}
-	} else {
-		g_warning ("failed to get content type of %s: %s", filename, error->message);
-		g_error_free (error);
-	}
-
-	/* fall back if we have not got a new enought s-m-i */
-	if (g_str_has_suffix (filename, ".icc")) {
-		ret = TRUE;
-		goto out;
-	}
-	if (g_str_has_suffix (filename, ".icm")) {
-		ret = TRUE;
-		goto out;
-	}
-	if (g_str_has_suffix (filename, ".ICC")) {
-		ret = TRUE;
-		goto out;
-	}
-	if (g_str_has_suffix (filename, ".ICM")) {
-		ret = TRUE;
-		goto out;
-	}
-out:
-	if (info != NULL)
-		g_object_unref (info);
-	g_free (filename);
-	return ret;
-}
-
 /**
  * gcm_utils_install_package:
  **/
@@ -244,78 +192,6 @@ gcm_utils_output_is_lcd (const gchar *output_name)
 	return FALSE;
 }
 
-/**
- * gcm_utils_mkdir_for_filename:
- **/
-gboolean
-gcm_utils_mkdir_for_filename (const gchar *filename, GError **error)
-{
-	gboolean ret = FALSE;
-	GFile *file;
-	GFile *parent_dir = NULL;
-
-	/* get a file from the URI / path */
-	file = g_file_new_for_path (filename);
-	if (file == NULL)
-		file = g_file_new_for_uri (filename);
-	if (file == NULL) {
-		g_set_error (error, 1, 0, "could not resolve file for %s", filename);
-		goto out;
-	}
-
-	/* get parent */
-	parent_dir = g_file_get_parent (file);
-	if (parent_dir == NULL) {
-		g_set_error (error, 1, 0, "could not get parent dir %s", filename);
-		goto out;
-	}
-
-	/* ensure desination exists */
-	ret = g_file_query_exists (parent_dir, NULL);
-	if (!ret) {
-		ret = g_file_make_directory_with_parents (parent_dir, NULL, error);
-		if (!ret)
-			goto out;
-	}
-out:
-	if (file != NULL)
-		g_object_unref (file);
-	if (parent_dir != NULL)
-		g_object_unref (parent_dir);
-	return ret;
-}
-
-/**
- * gcm_utils_mkdir_and_copy:
- **/
-gboolean
-gcm_utils_mkdir_and_copy (GFile *source, GFile *destination, GError **error)
-{
-	gboolean ret;
-	GFile *parent;
-
-	g_return_val_if_fail (source != NULL, FALSE);
-	g_return_val_if_fail (destination != NULL, FALSE);
-
-	/* get parent */
-	parent = g_file_get_parent (destination);
-
-	/* create directory */
-	if (!g_file_query_exists (parent, NULL)) {
-		ret = g_file_make_directory_with_parents (parent, NULL, error);
-		if (!ret)
-			goto out;
-	}
-
-	/* do the copy */
-	ret = g_file_copy (source, destination, G_FILE_COPY_OVERWRITE, NULL, NULL, NULL, error);
-	if (!ret)
-		goto out;
-out:
-	g_object_unref (parent);
-	return ret;
-}
-
 /**
  * gcm_utils_get_profile_destination:
  **/
@@ -441,80 +317,6 @@ gcm_utils_ensure_sensible_filename (gchar *data)
 	}
 }
 
-/**
- * gcm_utils_device_kind_to_profile_kind:
- **/
-CdProfileKind
-gcm_utils_device_kind_to_profile_kind (CdDeviceKind kind)
-{
-	CdProfileKind profile_kind;
-	switch (kind) {
-	case CD_DEVICE_KIND_DISPLAY:
-		profile_kind = CD_PROFILE_KIND_DISPLAY_DEVICE;
-		break;
-	case CD_DEVICE_KIND_CAMERA:
-	case CD_DEVICE_KIND_SCANNER:
-		profile_kind = CD_PROFILE_KIND_INPUT_DEVICE;
-		break;
-	case CD_DEVICE_KIND_PRINTER:
-		profile_kind = CD_PROFILE_KIND_OUTPUT_DEVICE;
-		break;
-	default:
-		profile_kind = CD_PROFILE_KIND_UNKNOWN;
-	}
-	return profile_kind;
-}
-
-/**
- * cd_rendering_intent_to_localized_text:
- **/
-const gchar *
-cd_rendering_intent_to_localized_text (CdRenderingIntent intent)
-{
-	if (intent == CD_RENDERING_INTENT_PERCEPTUAL) {
-		/* TRANSLATORS: rendering intent: you probably want to google this */
-		return _("Perceptual");
-	}
-	if (intent == CD_RENDERING_INTENT_RELATIVE_COLORIMETRIC) {
-		/* TRANSLATORS: rendering intent: you probably want to google this */
-		return _("Relative Colorimetric");
-	}
-	if (intent == CD_RENDERING_INTENT_SATURATION) {
-		/* TRANSLATORS: rendering intent: you probably want to google this */
-		return _("Saturation");
-	}
-	if (intent == CD_RENDERING_INTENT_ABSOLUTE_COLORIMETRIC) {
-		/* TRANSLATORS: rendering intent: you probably want to google this */
-		return _("Absolute Colorimetric");
-	}
-	return "unknown";
-}
-
-/**
- * cd_rendering_intent_to_localized_description:
- **/
-const gchar *
-cd_rendering_intent_to_localized_description (CdRenderingIntent intent)
-{
-	if (intent == CD_RENDERING_INTENT_PERCEPTUAL) {
-		/* TRANSLATORS: rendering intent: you probably want to google this */
-		return _("High quality photography");
-	}
-	if (intent == CD_RENDERING_INTENT_RELATIVE_COLORIMETRIC) {
-		/* TRANSLATORS: rendering intent: you probably want to google this */
-		return _("Precise color matching");
-	}
-	if (intent == CD_RENDERING_INTENT_SATURATION) {
-		/* TRANSLATORS: rendering intent: you probably want to google this */
-		return _("Graphs and presentations");
-	}
-	if (intent == CD_RENDERING_INTENT_ABSOLUTE_COLORIMETRIC) {
-		/* TRANSLATORS: rendering intent: you probably want to google this */
-		return _("Proofing devices");
-	}
-	return "unknown";
-}
-
 /**
  * cd_colorspace_to_localised_string:
  **/
